@@ -25,7 +25,10 @@
 """
 Module for handling /tokens APIs
 """
+from http.client import INTERNAL_SERVER_ERROR
+
 import connexion
+from fss_utils.http_errors import cors_response
 
 from fabric_cm.credmgr.credential_managers.oauth_credmgr import OAuthCredmgr
 from fabric_cm.credmgr.swagger_server.models.request import Request  # noqa: E501
@@ -37,6 +40,7 @@ from fabric_cm.credmgr.swagger_server.response.constants import HTTP_METHOD_POST
 from fabric_cm.credmgr.config import CONFIG_OBJ
 from fabric_cm.credmgr.logging import LOG
 
+
 def authorize(request):
     ci_logon_id_token = request.headers.get(VOUCH_ID_TOKEN, None)
     refresh_token = request.headers.get(VOUCH_REFRESH_TOKEN, None)
@@ -46,13 +50,13 @@ def authorize(request):
     return ci_logon_id_token, refresh_token, cookie
 
 
-def tokens_create_post(project_name=None, scope=None):  # noqa: E501
+def tokens_create_post(project_id, scope=None):  # noqa: E501
     """Generate Fabric OAuth tokens for an user
 
     Request to generate Fabric OAuth tokens for an user  # noqa: E501
 
-    :param project_name: Project Name
-    :type project_name: str
+    :param project_id: Project Id
+    :type project_id: str
     :param scope: Scope for which token is requested
     :type scope: str
 
@@ -67,7 +71,7 @@ def tokens_create_post(project_name=None, scope=None):  # noqa: E501
         credmgr = OAuthCredmgr()
         result = credmgr.create_token(ci_logon_id_token=ci_logon_id_token,
                                       refresh_token=refresh_token,
-                                      project=project_name,
+                                      project=project_id,
                                       scope=scope,
                                       cookie=cookie)
         response = Success.from_dict(result)
@@ -77,18 +81,18 @@ def tokens_create_post(project_name=None, scope=None):  # noqa: E501
     except Exception as ex:
         LOG.exception(ex)
         failure_counter.labels(HTTP_METHOD_POST, TOKENS_CREATE_URL).inc()
-        return str(ex), 500
+        return cors_response(status=INTERNAL_SERVER_ERROR, xerror=str(ex), body=str(ex))
 
 
-def tokens_refresh_post(body, project_name=None, scope=None):  # noqa: E501
+def tokens_refresh_post(body, project_id=None, scope=None):  # noqa: E501
     """Refresh FABRIC OAuth tokens for an user
 
     Request to refresh OAuth tokens for an user  # noqa: E501
 
     :param body:
     :type body: dict | bytes
-    :param project_name: Project Name
-    :type project_name: str
+    :param project_id: Project Id
+    :type project_id: str
     :param scope: Scope for which token is requested
     :type scope: str
 
@@ -101,14 +105,15 @@ def tokens_refresh_post(body, project_name=None, scope=None):  # noqa: E501
         ci_logon_id_token, refresh_token, cookie = authorize(connexion.request)
         credmgr = OAuthCredmgr()
         response = Success.from_dict(credmgr.refresh_token(refresh_token=body.refresh_token,
-                                                           project=project_name, scope=scope,
+                                                           project=project_id, scope=scope,
                                                            cookie=cookie))
         success_counter.labels(HTTP_METHOD_POST, TOKENS_REFRESH_URL).inc()
         return response
     except Exception as ex:
         LOG.exception(ex)
         failure_counter.labels(HTTP_METHOD_POST, TOKENS_REFRESH_URL).inc()
-        return str(ex), 500
+        msg = str(ex).replace("\n", "")
+        return cors_response(status=INTERNAL_SERVER_ERROR, xerror=msg, body=msg)
 
 
 def tokens_revoke_post(body):  # noqa: E501
@@ -131,5 +136,6 @@ def tokens_revoke_post(body):  # noqa: E501
     except Exception as ex:
         LOG.exception(ex)
         failure_counter.labels(HTTP_METHOD_POST, TOKENS_REVOKE_URL).inc()
-        return str(ex), 500
+        msg = str(ex).replace("\n", "")
+        return cors_response(status=INTERNAL_SERVER_ERROR, xerror=msg, body=msg)
     return {}
